<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://davidstockdalescrapcode.co.uk
 * @since      1.0.0
 *
 * @package    David_Scroller
 * @subpackage David_Scroller/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    David_Scroller
 * @subpackage David_Scroller/public
 * @author     David Stockdale <davidstockdale13@hotmail.co.uk>
 */
class David_Scroller_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $david_scroller    The ID of this plugin.
	 */
	private $david_scroller;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $david_scroller       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $david_scroller, $version ) {

		$this->david_scroller = $david_scroller;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in David_Scroller_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The David_Scroller_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->david_scroller, plugin_dir_url( __FILE__ ) . 'css/david-scroller-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in David_Scroller_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The David_Scroller_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		//wp_enqueue_script( $this->david_scroller, plugin_dir_url( __FILE__ ) . 'js/david-scroller-public.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script(
			'numscroller-1.0', // name your script so that you can attach other scripts and de-register, etc.
			plugin_dir_url( __FILE__ ) . 'js/numscroller-1.0.js', // this is the location of your script file
			array('jquery'), $this->version, false // this array lists the scripts upon which your script depends
		);

	}
	/**
	 * A shortcode for aquiring google sheet data (David Stockdale).
	 * 
	 * Shortcode should be something like this: 
	 * [get_sheet_value location="'Sheet Name'!Cell" api='API_KEY' sheet='SPREADSHEET-ID']
	 * OR (if you right click a cell and name it a "named range" you only need that name for location)
	 * [get_sheet_value location="Named Range" api='API_KEY' sheet='SPREADSHEET-ID']
	 * 
	 * EXAMPLE:
	 * [get_sheet_value location="'Summary Page'!C3" api='XXX_XXX' sheet='XXX-XXX-XXX']
	 * 
	 * Where to find API Key and SpreadSheet Id:
	 * API Key (to get this goto the "Google Developers Console" and create a key in the "Credentials" section).
	 * SpreadSheet Id: https://docs.google.com/spreadsheets/d/spreadsheetId/edit#gid=sheetId
	 */
	public function sheet_value_shortcode($atts) {
		$google_spreadsheet_ID = $atts['sheet'];

		$api_key = esc_attr( $atts['api']);

		$location = $atts['location'];

		$get_cell = new WP_Http();
		$cell_url = "https://sheets.googleapis.com/v4/spreadsheets/$google_spreadsheet_ID/values/$location?&key=$api_key";	
		$cell_response = $get_cell -> get( $cell_url);
		$json_body = json_decode($cell_response['body'],true);	
		$cell_value = $json_body['values'][0][0];
		return $cell_value;
	}
	
	
	
	
	/**
	 * Runs the "sheet_value_shortcode" and then uses the result
	 * to create a "numscroller" which it returns as HTML (David Stockdale).
	 * 
	 * ----------Shortcode Use Examples---------- 
	 * -----------------Required-----------------
	 * Location, Key and ID: [david_scroller location="'Summary Page'!C3" api_key=1 spreadsheet_id=2]
	 * OR
	 * Location (using "Named Range"), Key and ID: [david_scroller location="NamedRange1" api_key=1 spreadsheet_id=2]
	 * -----------------Optional-----------------
	 * Delay: [david_scroller location="'Summary Page'!C3" api_key=1 spreadsheet_id=2 delay=10]
	 * 
	 * Increment: [david_scroller location="'Summary Page'!C3" api_key=1 spreadsheet_id=2 increment=1]
	 * 
	 * Minimum: [david_scroller location="'Summary Page'!C3" api_key=1 spreadsheet_id=2 min=4]
	 * 
	 * Default: [david_scroller location="'Summary Page'!C3" api_key=1 spreadsheet_id=2 default=999]
	 * 
	 * All: [david_scroller location="'Summary Page'!C3" api_key=1 spreadsheet_id=2 delay=10 increment=1 min=4 default=999]
	 */
	public function david_scroller_shortcode($atts) {
		$sho = "[get_sheet_value location=";
		$sho .= '"';
		$sho .= $atts['location'];
		$sho .= '"';

		$sho .= " api=";
		$sho .= "'";
		/**
		 * API Key (to get this goto the "Google Developers Console"
		 * and create a key in the "Credentials" section).
		 */
		$sho .= get_option( 'api_key_array', false )[$atts['api_key']];
		$sho .= "'";

		$sho .= " sheet=";
		$sho .= "'";
		/**
		 * SpreadSheet Id: https://docs.google.com/spreadsheets/d/spreadsheetId/edit#gid=sheetId
		 * (REMEMBER TO MAKE THE SHPREADSHEET SHARABLE/ACCESSABLE BY LINK!)
		 */
		$sho .= get_option( 'spreadsheet_id_array', false )[$atts['spreadsheet_id']];
		$sho .= "'";

		$sho .= "]";

		ob_start(); //Start output buffer
		/**
		 * [get_sheet_value location="'Sheet Name'!Cell" api='API_KEY' sheet='SPREADSHEET-ID']
		 */
		echo do_shortcode($sho);
		$number = ob_get_contents(); //Grab output
		ob_end_clean(); //Discard output buffer

		if (!(isset($atts['min']->a)) && !empty($atts['min'])) {
			$min = $atts['min'];
		} else {
			$min = 1;
		}

		if (!(isset($atts['delay']->a)) && !empty($atts['delay'])) {
			$delay = $atts['delay'];
		} else {
			$delay = 5;
		}

		if (!(isset($atts['increment']->a)) && !empty($atts['increment'])) {
			$increment = $atts['increment'];
		} else {
			$increment = 10;
		}

		if (!(isset($atts['default']->a)) && !empty($atts['default'])) {
			$default = $atts['default'];
		} else {
			$default = 0;
		}

		return <<<HTML
		<html>
		<body>
		<span class="numscroller" data-min=$min data-max=$number data-delay=$delay data-increment=$increment>$default</span>
		</body>
		</html>
	HTML;
	}

}
